<?php
/**
 * Non-object helpers functions.
 *
 * @package StockSyncWithGoogleSheetForWooCommerce
 * @since 1.2.2
 */

// Exit if accessed directly.
defined('ABSPATH') || exit;

/**
 * Get an option from the options table
 */
if ( ! function_exists('ssgsw_get_option') ) {
	/**
	 * Get an option from the options table
	 *
	 * @param string $option_name The option name.
	 * @param mixed  $default     The default value.
	 * @return mixed
	 */
	function ssgsw_get_option( $option_name, $default = null ) {
		$value = get_option(SSGSW_PREFIX . $option_name);

		if ( ! $value ) {
			return $default;
		}

		return apply_filters( 'ssgsw_get_' . $option_name, $value );
	}
}

/**
 * Update an option in the options table
 */
if ( ! function_exists('ssgsw_update_option') ) {
	/**
	 * Update an option in the options table
	 *
	 * @param string $option_name The option name.
	 * @param mixed  $value       The value.
	 * @return bool
	 */
	function ssgsw_update_option( $option_name, $value ) {

		$value = apply_filters( 'ssgsw_update_' . $option_name, $value );

		do_action( 'ssgsw_before_update_' . $option_name, $value );

		$updated = update_option(SSGSW_PREFIX . $option_name, $value);

		if ( $updated ) {
			do_action( 'ssgsw_updated_' . $option_name, $value );
		}

		return $updated;
	}
}


/**
 * Get the app instance
 */
if ( ! function_exists('ssgsw') ) {
	/**
	 * Get the app instance
	 *
	 * @return \StockSyncWithGoogleSheetForWooCommerce\App
	 */
	function ssgsw() {
		return new \StockSyncWithGoogleSheetForWooCommerce\App();
	}
}